@@ -1,15 +1,7 @@
-## depreciated
-# # compute pair-wise weightes for soil-relation graph
-# .pair.wise.wts <- function(d, wt) {
-#   x <- d[[wt]]
-#   x <- x / sum(x)
-#   w <- outer(x, x, FUN='*')
-#   return(w)
-# }
 
 
 ## new method based on dissimilarity eval of community matrix
-component.adj.matrix <-function(d, mu='mukey', co='compname', wt='comppct_r', method='community.matrix', standardization='max', metric='jaccard', rm.orphans=TRUE, similarity=TRUE) {
+component.adj.matrix <-function(d, mu='mukey', co='compname', wt='comppct_r', method='community.matrix', standardization='max', metric='jaccard', rm.orphans=TRUE, similarity=TRUE, return.comm.matrix=FALSE) {
 	
   # appease R CMD check
   .wt <- NULL
@@ -67,6 +59,10 @@ component.adj.matrix <-function(d, mu='mukey', co='compname', wt='comppct_r', me
   }
   
   
+  ### Note: when using a limited number of "exemplars" (typically map units) the resulting
+  ###       adjacency matrix may contain 0's using this method
+  ###       https://github.com/ncss-tech/sharpshootR/issues/4
+  
   # default method, based on ideas from ecological community matrix analysis
   if(method == 'community.matrix') {
     
@@ -82,9 +78,19 @@ component.adj.matrix <-function(d, mu='mukey', co='compname', wt='comppct_r', me
     d.mat <- as.matrix(d.wide[, -1])
     dimnames(d.mat)[[1]] <- d.wide[[co]]
     
-    # convert community matrix into dissimilarity matrix
+    # optionally return psuedo community matrix
+    if(return.comm.matrix) {
+      return(d.mat)
+    }
+    
+    
     ## standardization method and distance metric MATTER
-    m <- vegdist(decostand(d.mat, method=standardization), method=metric)
+    # convert community matrix into dissimilarity matrix
+    # optional standardization
+    if(standardization != 'none')
+      d.mat <- decostand(d.mat, method=standardization)
+    # distance matrix
+    m <- vegdist(d.mat, method=metric)
     
     # convert to similarity matrix: S = max(D) - D [Kaufman & Rousseeuw]
     if(similarity == TRUE) {
